summaryrefslogtreecommitdiffstats
path: root/scripts/automation/trex_control_plane/client_utils/trex_yaml_gen.py
diff options
context:
space:
mode:
authorDan Klein <danklei@cisco.com>2015-10-06 01:53:24 +0300
committerDan Klein <danklei@cisco.com>2015-10-06 01:53:24 +0300
commitada8c62d7393e22cee7fccf9eb1b16b8ebe3c7c8 (patch)
tree1b46be91bdbab97071ee2027e687c11e41fca795 /scripts/automation/trex_control_plane/client_utils/trex_yaml_gen.py
parent9629c9953516281d4bdaad1ed63d145de336a983 (diff)
Removed any "T-Rex" string out of the code and documentation, using GREP!
Diffstat (limited to 'scripts/automation/trex_control_plane/client_utils/trex_yaml_gen.py')
-rwxr-xr-xscripts/automation/trex_control_plane/client_utils/trex_yaml_gen.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/scripts/automation/trex_control_plane/client_utils/trex_yaml_gen.py b/scripts/automation/trex_control_plane/client_utils/trex_yaml_gen.py
index 755674ea..c26fef29 100755
--- a/scripts/automation/trex_control_plane/client_utils/trex_yaml_gen.py
+++ b/scripts/automation/trex_control_plane/client_utils/trex_yaml_gen.py
@@ -7,7 +7,7 @@ import os
class CTRexYaml(object):
"""
This class functions as a YAML generator according to T-Rex YAML format.
CTRexYaml is compatible with both Python 2 and Python 3.
"""
@@ -38,7 +38,7 @@ class CTRexYaml(object):
:parameters:
trex_files_path : str
a path (on T-Rex server side) for the pcap files using which T-Rex can access it.
"""
self.yaml_obj = list(CTRexYaml.YAML_TEMPLATE)
@@ -114,7 +114,7 @@ class CTRexYaml(object):
:parameters:
None
- :reaturn:
+ :return:
None
"""
@@ -193,7 +193,7 @@ class CTRexYaml(object):
"""
Returns a list of all files related to the YAML object, including the YAML filename itself.
- .. tip:: This method is especially useful for listing all the files that should be pushed to T-Rex server as part of the same yaml selection.
+ .. tip:: This method is especially useful for listing all the files that should be pushed to TRex server as part of the same yaml selection.
:parameters:
None
@@ -7,7 +7,7 @@ import os
class CTRexYaml(object):
"""
- This class functions as a YAML generator according to T-Rex YAML format.
+ This class functions as a YAML generator according to TRex YAML format.
CTRexYaml is compatible with both Python 2 and Python 3.
"""
@@ -38,7 +38,7 @@ class CTRexYaml(object):
:parameters:
trex_files_path : str
- a path (on T-Rex server side) for the pcap files using which T-Rex can access it.
+ a path (on TRex server side) for the pcap files using which TRex can access it.
"""
self.yaml_obj = list(CTRexYaml.YAML_TEMPLATE)